"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useIsKeyboardConnected = exports.keyboardStatusListener = exports.isKeyboardConnected = void 0;
var _react = require("react");
var _reactNative = require("react-native");
const KEYBOARD_STATUS_EVENT = 'keyboardStatus';
const LINKING_ERROR = `The package 'react-native-is-keyboard-connected' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo Go\n';

// @ts-expect-error
const isTurboModuleEnabled = global.__turboModuleProxy != null;
const IsKeyboardConnectedModule = isTurboModuleEnabled ? require('./nativeSpecs/NativeIsKeyboardConnected').default : _reactNative.NativeModules.IsKeyboardConnected;
const IsKeyboardConnected = IsKeyboardConnectedModule ? IsKeyboardConnectedModule : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});
const isKeyboardConnected = () => {
  return IsKeyboardConnected.isKeyboardConnected();
};
exports.isKeyboardConnected = isKeyboardConnected;
const keyboardStatusListener = callback => {
  const eventEmitter = new _reactNative.NativeEventEmitter(IsKeyboardConnected);
  const eventListener = eventEmitter.addListener(KEYBOARD_STATUS_EVENT, callback);
  return () => eventListener.remove();
};
exports.keyboardStatusListener = keyboardStatusListener;
const useIsKeyboardConnected = () => {
  const [isConnected, setIsConnected] = (0, _react.useState)(false);
  (0, _react.useEffect)(() => {
    const removeListener = keyboardStatusListener(e => setIsConnected(e.status));
    isKeyboardConnected().then(status => setIsConnected(status));
    return removeListener;
  }, []);
  return isConnected;
};
exports.useIsKeyboardConnected = useIsKeyboardConnected;
//# sourceMappingURL=index.js.map